# hckr
[![PyPI - Version](https://img.shields.io/pypi/v/hckr.svg)](https://pypi.org/project/hckr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hckr.svg)](https://pypi.org/project/hckr)
[![Build](https://github.com/pateash/hckr/actions/workflows/build.yml/badge.svg)](https://github.com/pateash/hckr/actions/workflows/build.yml)
[![Dependabot](https://github.com/pateash/hckr/actions/workflows/dependabot/dependabot-updates/badge.svg)](https://github.com/pateash/hckr/actions/workflows/dependabot/dependabot-updates)
[![CodeQL](https://github.com/pateash/hckr/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/pateash/hckr/actions/workflows/github-code-scanning/codeql)

hckr - Awesome CLI for devs

## Table of Contents

- [Installation](#installation)
- [License](#license)
- [Sponsors](#sponsors)

## Installation

```console
pip install hckr
```

## License

`hckr` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Contributing
Please find contributing guide here [CONTRIBUTING.md](CONTRIBUTING.md)

## Sponsors
> Built using Jetbrains Products
![Jetbrains](https://www.jetbrains.com/company/brand/img/jetbrains_logo.png)
